@@ -163,6 +163,13 @@ atomblock(sdfset[[1]])[1:4,]
  sdfstr
  as(sdfstr, "SDFset") 
 
+## ----eval=TRUE, tidy=FALSE------------------------------------------------------------------------
+ v3 <- read.SDFset("https://cluster.hpcc.ucr.edu/~tgirke/Documents/R_BioCond/Samples/v3000.sdf",extendedAttributes=TRUE) 
+
+## ----eval=TRUE, tidy=FALSE------------------------------------------------------------------------
+getAtomAttr(v3[[1]],17,"CHG")
+getBondAttr(v3[[1]],10,"CFG")
+
 ## ----eval=FALSE, tidy=FALSE-----------------------------------------------------------------------
 #   data(smisample); smiset <- smisample
 #   write.SMI(smiset[1:4], file="sub.smi")
